@@ -1,5 +1,5 @@
 #!/usr/bin/python3
-# SPDX-FileCopyrightText: 2004-2025 Univention GmbH
+# SPDX-FileCopyrightText: 2004-2026 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 #
 from __future__ import annotations
@@ -224,6 +224,6 @@ def postrun() -> None:
     ud.debug(ud.LISTENER, ud.INFO, 'Restarting fetchmail-daemon')
     listener.setuid(0)
     try:
-        listener.run('systemctl', ['restart', 'fetchmail'], uid=0)
+        listener.run('/usr/bin/systemctl', ['systemctl', 'restart', 'fetchmail'], uid=0)
     finally:
         listener.unsetuid()
